@@ -41,6 +41,7 @@ def do_train(cfg, arguments,
         summary_writer = SummaryWriter(log_dir=os.path.join(cfg.OUTPUT_DIR, 'tf_logs'))
 
     log_step = cfg.TRAIN.LOG_STEP
+    save_step = 1000
     save_epoch = cfg.TRAIN.SAVE_EPOCH
     eval_epoch = cfg.TRAIN.EVAL_EPOCH
     max_epoch = cfg.TRAIN.MAX_EPOCH
@@ -119,6 +120,8 @@ def do_train(cfg, arguments,
             if (iteration + 1) % log_step == 0:
                 logger.info(log_iter_stats(
                     iteration, epoch_iters, cur_epoch, max_epoch, optimizer.param_groups[0]['lr'], meters))
+            if is_master_proc() and (iteration + 1) % save_step == 0:
+                check_pointer.save("model_{:08d}".format(iteration + 1), **arguments)
             if is_master_proc() and summary_writer:
                 global_step = (cur_epoch - 1) * epoch_iters + (iteration + 1)
                 for name, meter in meters.meters.items():
